==> chk-0.1.5.tar.gz: chk-0.1.5/README.md <==
# Chkware

![Chkware | Test management for api era](https://raw.githubusercontent.com/wiki/chkware/cli/github-readme-01.png)

[![PyPI version](https://badge.fury.io/py/chk.svg)](https://badge.fury.io/py/chk)
[![Python 3.8](https://img.shields.io/badge/python-3.10-red.svg)](https://www.python.org/downloads/release/python-3102/)
[![Twitter](https://img.shields.io/twitter/url/https/twitter.com/chkware.svg?style=social&label=Follow%20%40chkware)](https://twitter.com/chkware)
> Test management for API era.

### Introduction

API tests management is not easy to develop, and maintain. It requires multitude of knowledge of programming libraries, business scenarios, infrastructure details, etc - unless you use ***chkware***.

***chkware*** (pronounced as */check:ware/*) helps you write accurate, robust, and expressive feature tests for your API in less time.
 
Read [more value propositions](https://github.com/chkware/cli/wiki/1.-Introduction) here. Find [changelog](docs/CHANGELOG.md) here.

### Setup

With [**Python 3.10**](https://www.python.org/downloads/) and [**Pipx**](https://pypa.github.io/pipx/installation/#install-pipx) preinstalled, run following in your terminal to get ***chkware*** installed.

```bash
$ python -m pipx install chk
```

Jump to the [setup guide](https://github.com/chkware/cli/wiki/2.-Setup) for different ways to install ***chkware***.

### Usage

[Get started](https://github.com/chkware/cli/wiki/3.-Quick-start) quickly here.
Find [More examples](https://github.com/chkware/cli/wiki/4.-More-examples) here

### Contribute

Read [contribution guide](docs/CONTRIBUTING.md) and [code of conduct](docs/CODE_OF_CONDUCT.md) to start contributions.

---
Licensed under [MPL v2.0](/LICENSE) | Follow [@chkware](https://twitter.com/chkware) on Twitter | [`chk` project](https://pypi.org/project/chk/) on PyPi

==> chk-0.3.2.tar.gz: chk-0.3.2/README.md <==
# Chkware

![Chkware | Test management for api era](docs/github-readme-01.png)

[![PyPI version](https://badge.fury.io/py/chk.svg)](https://badge.fury.io/py/chk)
[![Python 3.8](https://img.shields.io/badge/python-3.10-red.svg)](https://www.python.org/downloads/release/python-3102/)
[![Twitter](https://img.shields.io/twitter/url/https/twitter.com/chkware.svg?style=social&label=Follow%20%40chkware)](https://twitter.com/chkware)
> Test management for API era.

### Introduction

API tests management is not easy to develop, and maintain. It requires multitude of knowledge of programming libraries, business scenarios, infrastructure details, etc - unless you use ***chkware***.

***chkware*** (pronounced as */check:ware/*) helps you write accurate, robust, and expressive feature tests for your API in less time.
 
Read [more value propositions](https://chkware.github.io/introduction) here. Find [changelog](docs/CHANGELOG.md) here.

### Setup

With [**Python 3.10**](https://www.python.org/downloads/) and [**Pipx**](https://pypa.github.io/pipx/installation/#install-pipx) preinstalled, run following in your terminal to get ***chkware*** installed.

```bash
$ pipx install chk
```

Jump to the [setup guide](https://chkware.github.io/setup) for different ways to install ***chkware***.

### Usage

[Get started](https://chkware.github.io/quick-start) quickly here.
Find [more examples usage](https://chkware.github.io/examples), and [reference](https://chkware.github.io/reference) here, 

### Contribute

Read [contribution guide](docs/CONTRIBUTING.md) and [code of conduct](docs/CODE_OF_CONDUCT.md) to start contributions.

---
Licensed under [MPL v2.0](/LICENSE) | Follow [@chkware](https://twitter.com/chkware) on Twitter | [`chk` project](https://pypi.org/project/chk/) on PyPi
